window.Gleam.initSearch([{"doc":"glexif","title":"glexif","content":"# glexif\n\n[![Package Version](https://img.shields.io/hexpm/v/glexif)](https://hex.pm/packages/glexif)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glexif/)\n\nA module for parsing out EXIF data from JPEG files.\n\n```sh\ngleam add glexif\n```\n\n```gleam\nimport glexif\n\npub fn main() {\n\n  glexif.get_exif_data_for_file(&quot;test/fixtures/test.jpeg&quot;)\n  |&gt; should.equal(exif_tag.ExifTagRecord(\n    make: Some(&quot;Apple&quot;),\n    model: Some(&quot;iPhone 14 Pro&quot;),\n    orientation: Some(orientation.Rotate90CW),\n    x_resolution: Some(72),\n    y_resolution: Some(72),\n    resolution_unit: Some(resolution_unit.Inches),\n    software: Some(&quot;17.2.1&quot;),\n    modify_date: Some(&quot;2024:02:18 17:34:57&quot;),\n    host_computer: Some(&quot;iPhone 14 Pro&quot;),\n    y_cb_cr_positioning: Some(y_cb_cr_positioning.Centered),\n    exposure_time: Some(Fraction(1, 179)),\n    f_number: Some(Fraction(89, 50)),\n    exposure_program: Some(exposure_program.ProgramAE),\n    iso: Some(64),\n    exif_version: Some(&quot;0232&quot;),\n    date_time_original: Some(&quot;2024:02:18 17:34:57&quot;),\n    create_date: Some(&quot;2024:02:18 17:34:57&quot;),\n    offset_time: Some(&quot;-06:00&quot;),\n    offset_time_original: Some(&quot;-06:00&quot;),\n    offset_time_digitized: Some(&quot;-06:00&quot;),\n    components_configuration: Some([\n      components_configuration.Y,\n      components_configuration.Cb,\n      components_configuration.Cr,\n      components_configuration.NA,\n    ]),\n    // TODO: convert this to seconds instead of the raw fraction\n    shutter_speed_value: Some(Fraction(124_929, 16_690)),\n    // TODO: convert this to the human readable value that it should be\n    aperature_value: Some(Fraction(163_775, 98_437)),\n    brightness_value: Some(5.389648033126294),\n    exposure_compensation: Some(Fraction(0, 1)),\n    metering_mode: Some(metering_mode.MultiSegement),\n    flash: Some(OffDidNotFire),\n    // TODO: Need units? Or is it always millimeters? ExifTool rounds to 1 decimal, should I do that too?\n    focal_length: Some(6.86),\n    subject_area: Some([2009, 1505, 2208, 1324]),\n    // TODO: parse out maker data. This is a whole ball of wax and I&#39;m kicking the can down the road\n    maker_data: Some(exif_tag.TBD),\n    sub_sec_time_original: Some(&quot;289&quot;),\n    sub_sec_time_digitized: Some(&quot;289&quot;),\n    flash_pix_version: Some(&quot;0100&quot;),\n    color_space: Some(color_space.Uncalibrated),\n    exif_image_width: Some(4032),\n    exif_image_height: Some(3024),\n    sensing_method: Some(sensing_method.OneChipColorArea),\n    scene_type: Some(scene_type.DirectlyPhotographed),\n    exposure_mode: Some(exposure_mode.Auto),\n    white_balance: Some(white_balance.Auto),\n    focal_length_in_35_mm_format: Some(24),\n    scene_capture_type: Some(scene_capture_type.Standard),\n    //TODO: Convert these 4 rational numbers to something useful\n    lens_info: Some([\n      Fraction(1_551_800, 699_009),\n      Fraction(9, 1),\n      Fraction(1_244_236, 699_009),\n      Fraction(14, 5),\n    ]),\n    lens_make: Some(&quot;Apple&quot;),\n    lens_model: Some(&quot;iPhone 14 Pro back triple camera 6.86mm f/1.78&quot;),\n    composite_image: Some(composite_image.GeneralCompositeImage),\n    gps_latitude_ref: Some(&quot;N&quot;),\n    gps_latitude: Some(gps_coordinates.GPSCoordinates(44, 58, 29.31)),\n    gps_longitude_ref: Some(&quot;W&quot;),\n    gps_longitude: Some(gps_coordinates.GPSCoordinates(93, 15, 35.93)),\n    gps_altitude_ref: Some(gps_altitude_ref.AboveSeaLevel),\n    gps_altitude: Some(245.97845468053492),\n  ))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glexif&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glexif/exif_tags/color_space","title":"ColorSpace","content":"pub type ColorSpace {\n  SRGB\n  AdobeRGB\n  WideGamutRGB\n  ICCProfile\n  Uncalibrated\n  InvalidColorSpace\n}\n\nSRGB\n\n\nAdobeRGB\n\n\nWideGamutRGB\n\n\nICCProfile\n\n\nUncalibrated\n\n\nInvalidColorSpace\n\n\nSynonyms:\nglexif/exif_tags/color_space.ColorSpace\nglexif/exif_tags/color_space ColorSpace","url":"glexif/exif_tags/color_space.html#ColorSpace"},{"doc":"glexif/exif_tags/color_space","title":"glexif/exif_tags/color_space","content":"","url":"glexif/exif_tags/color_space.html"},{"doc":"glexif/exif_tags/components_configuration","title":"ComponentsConfiguration","content":"pub type ComponentsConfiguration {\n  Y\n  Cb\n  Cr\n  R\n  G\n  B\n  NA\n  InvalidComponentsConfiguration\n}\n\nY\n\n\nCb\n\n\nCr\n\n\nR\n\n\nG\n\n\nB\n\n\nNA\n\n\nInvalidComponentsConfiguration\n\n\nSynonyms:\nglexif/exif_tags/components_configuration.ComponentsConfiguration\nglexif/exif_tags/components_configuration ComponentsConfiguration","url":"glexif/exif_tags/components_configuration.html#ComponentsConfiguration"},{"doc":"glexif/exif_tags/components_configuration","title":"glexif/exif_tags/components_configuration","content":"","url":"glexif/exif_tags/components_configuration.html"},{"doc":"glexif/exif_tags/composite_image","title":"CompositeImage","content":"pub type CompositeImage {\n  Unknown\n  NotACompositeImage\n  GeneralCompositeImage\n  CompositeImageCapturedWhileShooting\n  InvalidCompositeImage\n}\n\nUnknown\n\n\nNotACompositeImage\n\n\nGeneralCompositeImage\n\n\nCompositeImageCapturedWhileShooting\n\n\nInvalidCompositeImage\n\n\nSynonyms:\nglexif/exif_tags/composite_image.CompositeImage\nglexif/exif_tags/composite_image CompositeImage","url":"glexif/exif_tags/composite_image.html#CompositeImage"},{"doc":"glexif/exif_tags/composite_image","title":"glexif/exif_tags/composite_image","content":"","url":"glexif/exif_tags/composite_image.html"},{"doc":"glexif/exif_tags/exposure_mode","title":"ExposureMode","content":"pub type ExposureMode {\n  Auto\n  Manual\n  AutoBracket\n  InvalidExposureMode\n}\n\nAuto\n\n\nManual\n\n\nAutoBracket\n\n\nInvalidExposureMode\n\n\nSynonyms:\nglexif/exif_tags/exposure_mode.ExposureMode\nglexif/exif_tags/exposure_mode ExposureMode","url":"glexif/exif_tags/exposure_mode.html#ExposureMode"},{"doc":"glexif/exif_tags/exposure_mode","title":"glexif/exif_tags/exposure_mode","content":"","url":"glexif/exif_tags/exposure_mode.html"},{"doc":"glexif/exif_tags/exposure_program","title":"ExposureProgram","content":"pub type ExposureProgram {\n  NotDefined\n  Manual\n  ProgramAE\n  AperturePriorityAE\n  ShutterSpeedPriorityAE\n  Creative\n  Action\n  Portrait\n  Landscape\n  Bulb\n  InvalidExposureProgram\n}\n\nNotDefined\n\n\nManual\n\n\nProgramAE\n\n\nAperturePriorityAE\n\n\nShutterSpeedPriorityAE\n\n\nCreative\n\n\nAction\n\n\nPortrait\n\n\nLandscape\n\n\nBulb\n\n\nInvalidExposureProgram\n\n\nSynonyms:\nglexif/exif_tags/exposure_program.ExposureProgram\nglexif/exif_tags/exposure_program ExposureProgram","url":"glexif/exif_tags/exposure_program.html#ExposureProgram"},{"doc":"glexif/exif_tags/exposure_program","title":"glexif/exif_tags/exposure_program","content":"","url":"glexif/exif_tags/exposure_program.html"},{"doc":"glexif/exif_tags/flash","title":"Flash","content":"pub type Flash {\n  NoFlash\n  Fired\n  FiredReturnNotDetected\n  FiredReturnDetected\n  OnDidNotFire\n  OnFired\n  OnReturnNotDetected\n  OnReturnDetected\n  OffDidNotFire\n  OffDidNotFireReturnNotDetected\n  AutoDidNotFire\n  AutoFired\n  AutoFiredReturnNotDetected\n  AutoFiredReturnDetected\n  NoFlashFunction\n  OffNoFlashFunction\n  FiredRedEyeReduction\n  FiredRedEyeReductionReturnNotDetected\n  FiredRedEyeReductionReturnDetected\n  OnRedEyeReduction\n  OnRedEyeReductionReturnNotDetected\n  OnRedEyeReductionReturnDetected\n  OffRedEyeReduction\n  AutoDidNotFireRedEyeReduction\n  AutoFiredRedEyeReduction\n  AutoFiredRedEyeReductionReturnNotDetected\n  AutoFiredRedEyeReductionReturnDetected\n  InvalidFlash\n}\n\nNoFlash\n\n\nFired\n\n\nFiredReturnNotDetected\n\n\nFiredReturnDetected\n\n\nOnDidNotFire\n\n\nOnFired\n\n\nOnReturnNotDetected\n\n\nOnReturnDetected\n\n\nOffDidNotFire\n\n\nOffDidNotFireReturnNotDetected\n\n\nAutoDidNotFire\n\n\nAutoFired\n\n\nAutoFiredReturnNotDetected\n\n\nAutoFiredReturnDetected\n\n\nNoFlashFunction\n\n\nOffNoFlashFunction\n\n\nFiredRedEyeReduction\n\n\nFiredRedEyeReductionReturnNotDetected\n\n\nFiredRedEyeReductionReturnDetected\n\n\nOnRedEyeReduction\n\n\nOnRedEyeReductionReturnNotDetected\n\n\nOnRedEyeReductionReturnDetected\n\n\nOffRedEyeReduction\n\n\nAutoDidNotFireRedEyeReduction\n\n\nAutoFiredRedEyeReduction\n\n\nAutoFiredRedEyeReductionReturnNotDetected\n\n\nAutoFiredRedEyeReductionReturnDetected\n\n\nInvalidFlash\n\n\nSynonyms:\nglexif/exif_tags/flash.Flash\nglexif/exif_tags/flash Flash","url":"glexif/exif_tags/flash.html#Flash"},{"doc":"glexif/exif_tags/flash","title":"glexif/exif_tags/flash","content":"","url":"glexif/exif_tags/flash.html"},{"doc":"glexif/exif_tags/gps_altitude_ref","title":"GPSAltitudeRef","content":"pub type GPSAltitudeRef {\n  AboveSeaLevel\n  BelowSeaLevel\n  InvalidGPSAltitudeRef\n}\n\nAboveSeaLevel\n\n\nBelowSeaLevel\n\n\nInvalidGPSAltitudeRef\n\n\nSynonyms:\nglexif/exif_tags/gps_altitude_ref.GPSAltitudeRef\nglexif/exif_tags/gps_altitude_ref GPSAltitudeRef","url":"glexif/exif_tags/gps_altitude_ref.html#GPSAltitudeRef"},{"doc":"glexif/exif_tags/gps_altitude_ref","title":"glexif/exif_tags/gps_altitude_ref","content":"","url":"glexif/exif_tags/gps_altitude_ref.html"},{"doc":"glexif/exif_tags/metering_mode","title":"MeteringMode","content":"pub type MeteringMode {\n  UnknownMeteringMode\n  Average\n  CenterWeightedAverage\n  Spot\n  MultiSpot\n  MultiSegement\n  Partial\n  Other\n  InvalidMeteringMode\n}\n\nUnknownMeteringMode\n\n\nAverage\n\n\nCenterWeightedAverage\n\n\nSpot\n\n\nMultiSpot\n\n\nMultiSegement\n\n\nPartial\n\n\nOther\n\n\nInvalidMeteringMode\n\n\nSynonyms:\nglexif/exif_tags/metering_mode.MeteringMode\nglexif/exif_tags/metering_mode MeteringMode","url":"glexif/exif_tags/metering_mode.html#MeteringMode"},{"doc":"glexif/exif_tags/metering_mode","title":"glexif/exif_tags/metering_mode","content":"","url":"glexif/exif_tags/metering_mode.html"},{"doc":"glexif/exif_tags/orientation","title":"Orientation","content":"pub type Orientation {\n  Horizontal\n  MirrorHorizontal\n  Rotate180\n  MirrorVertical\n  MirrorHorizontalAndRotate270CW\n  Rotate90CW\n  MirrorHorizontalAndRotate90CW\n  Rotate270CW\n  InvalidOrientation\n}\n\nHorizontal\n\n\nMirrorHorizontal\n\n\nRotate180\n\n\nMirrorVertical\n\n\nMirrorHorizontalAndRotate270CW\n\n\nRotate90CW\n\n\nMirrorHorizontalAndRotate90CW\n\n\nRotate270CW\n\n\nInvalidOrientation\n\n\nSynonyms:\nglexif/exif_tags/orientation.Orientation\nglexif/exif_tags/orientation Orientation","url":"glexif/exif_tags/orientation.html#Orientation"},{"doc":"glexif/exif_tags/orientation","title":"glexif/exif_tags/orientation","content":"","url":"glexif/exif_tags/orientation.html"},{"doc":"glexif/exif_tags/resolution_unit","title":"ResolutionUnit","content":"pub type ResolutionUnit {\n  NoResolutionTagUnit\n  Inches\n  Centimeters\n  InvalidResolutionUnit\n}\n\nNoResolutionTagUnit\n\n\nInches\n\n\nCentimeters\n\n\nInvalidResolutionUnit\n\n\nSynonyms:\nglexif/exif_tags/resolution_unit.ResolutionUnit\nglexif/exif_tags/resolution_unit ResolutionUnit","url":"glexif/exif_tags/resolution_unit.html#ResolutionUnit"},{"doc":"glexif/exif_tags/resolution_unit","title":"glexif/exif_tags/resolution_unit","content":"","url":"glexif/exif_tags/resolution_unit.html"},{"doc":"glexif/exif_tags/scene_capture_type","title":"SceneCaptureType","content":"pub type SceneCaptureType {\n  Standard\n  Landscape\n  Portrait\n  Night\n  Other\n  InvalidSceneCaptureType\n}\n\nStandard\n\n\nLandscape\n\n\nPortrait\n\n\nNight\n\n\nOther\n\n\nInvalidSceneCaptureType\n\n\nSynonyms:\nglexif/exif_tags/scene_capture_type.SceneCaptureType\nglexif/exif_tags/scene_capture_type SceneCaptureType","url":"glexif/exif_tags/scene_capture_type.html#SceneCaptureType"},{"doc":"glexif/exif_tags/scene_capture_type","title":"glexif/exif_tags/scene_capture_type","content":"","url":"glexif/exif_tags/scene_capture_type.html"},{"doc":"glexif/exif_tags/scene_type","title":"SceneType","content":"pub type SceneType {\n  DirectlyPhotographed\n}\n\nDirectlyPhotographed\n\n\nSynonyms:\nglexif/exif_tags/scene_type.SceneType\nglexif/exif_tags/scene_type SceneType","url":"glexif/exif_tags/scene_type.html#SceneType"},{"doc":"glexif/exif_tags/scene_type","title":"glexif/exif_tags/scene_type","content":"","url":"glexif/exif_tags/scene_type.html"},{"doc":"glexif/exif_tags/sensing_method","title":"SensingMethod","content":"pub type SensingMethod {\n  SensingMethodNotDefined\n  OneChipColorArea\n  TwoChipColorArea\n  ThreeChipColorArea\n  ColorSequentialArea\n  Trilinear\n  ColorSequentialLinear\n  InvalidSensingMethod\n}\n\nSensingMethodNotDefined\n\n\nOneChipColorArea\n\n\nTwoChipColorArea\n\n\nThreeChipColorArea\n\n\nColorSequentialArea\n\n\nTrilinear\n\n\nColorSequentialLinear\n\n\nInvalidSensingMethod\n\n\nSynonyms:\nglexif/exif_tags/sensing_method.SensingMethod\nglexif/exif_tags/sensing_method SensingMethod","url":"glexif/exif_tags/sensing_method.html#SensingMethod"},{"doc":"glexif/exif_tags/sensing_method","title":"glexif/exif_tags/sensing_method","content":"","url":"glexif/exif_tags/sensing_method.html"},{"doc":"glexif/exif_tags/white_balance","title":"WhiteBalance","content":"pub type WhiteBalance {\n  Auto\n  Manual\n  InvalidWhiteBalance\n}\n\nAuto\n\n\nManual\n\n\nInvalidWhiteBalance\n\n\nSynonyms:\nglexif/exif_tags/white_balance.WhiteBalance\nglexif/exif_tags/white_balance WhiteBalance","url":"glexif/exif_tags/white_balance.html#WhiteBalance"},{"doc":"glexif/exif_tags/white_balance","title":"glexif/exif_tags/white_balance","content":"","url":"glexif/exif_tags/white_balance.html"},{"doc":"glexif/exif_tags/y_cb_cr_positioning","title":"YCbCrPositioning","content":"pub type YCbCrPositioning {\n  Centered\n  CoSited\n  InvalidYCbCrPositioning\n}\n\nCentered\n\n\nCoSited\n\n\nInvalidYCbCrPositioning\n\n\nSynonyms:\nglexif/exif_tags/y_cb_cr_positioning.YCbCrPositioning\nglexif/exif_tags/y_cb_cr_positioning YCbCrPositioning","url":"glexif/exif_tags/y_cb_cr_positioning.html#YCbCrPositioning"},{"doc":"glexif/exif_tags/y_cb_cr_positioning","title":"glexif/exif_tags/y_cb_cr_positioning","content":"","url":"glexif/exif_tags/y_cb_cr_positioning.html"},{"doc":"glexif/units/fraction","title":"Fraction","content":"pub type Fraction {\n  Fraction(numerator: Int, denominator: Int)\n}\n\nFraction(numerator: Int, denominator: Int)\n\n\nSynonyms:\nglexif/units/fraction.Fraction\nglexif/units/fraction Fraction","url":"glexif/units/fraction.html#Fraction"},{"doc":"glexif/units/fraction","title":"glexif/units/fraction","content":"","url":"glexif/units/fraction.html"},{"doc":"glexif/units/gps_coordinates","title":"GPSCoordinates","content":"pub type GPSCoordinates {\n  GPSCoordinates(degrees: Int, minutes: Int, seconds: Float)\n  InvalidGPSCoordinates\n}\n\nGPSCoordinates(degrees: Int, minutes: Int, seconds: Float)\n\n\nInvalidGPSCoordinates\n\n\nSynonyms:\nglexif/units/gps_coordinates.GPSCoordinates\nglexif/units/gps_coordinates GPSCoordinates","url":"glexif/units/gps_coordinates.html#GPSCoordinates"},{"doc":"glexif/units/gps_coordinates","title":"glexif/units/gps_coordinates","content":"","url":"glexif/units/gps_coordinates.html"},{"doc":"glexif/exif_tag","title":"ExifTagRecord","content":"pub type ExifTagRecord {\n  ExifTagRecord(\n    make: Option(String),\n    model: Option(String),\n    orientation: Option(Orientation),\n    x_resolution: Option(Int),\n    y_resolution: Option(Int),\n    resolution_unit: Option(ResolutionUnit),\n    software: Option(String),\n    modify_date: Option(String),\n    host_computer: Option(String),\n    y_cb_cr_positioning: Option(YCbCrPositioning),\n    exposure_time: Option(Fraction),\n    f_number: Option(Fraction),\n    exposure_program: Option(ExposureProgram),\n    iso: Option(Int),\n    exif_version: Option(String),\n    date_time_original: Option(String),\n    create_date: Option(String),\n    offset_time: Option(String),\n    offset_time_original: Option(String),\n    offset_time_digitized: Option(String),\n    components_configuration: Option(\n      List(ComponentsConfiguration),\n    ),\n    shutter_speed_value: Option(Fraction),\n    aperature_value: Option(Fraction),\n    brightness_value: Option(Float),\n    exposure_compensation: Option(Fraction),\n    metering_mode: Option(MeteringMode),\n    flash: Option(Flash),\n    focal_length: Option(Float),\n    subject_area: Option(List(Int)),\n    maker_data: Option(TBD),\n    sub_sec_time_original: Option(String),\n    sub_sec_time_digitized: Option(String),\n    flash_pix_version: Option(String),\n    color_space: Option(ColorSpace),\n    exif_image_width: Option(Int),\n    exif_image_height: Option(Int),\n    sensing_method: Option(SensingMethod),\n    scene_type: Option(SceneType),\n    exposure_mode: Option(ExposureMode),\n    white_balance: Option(WhiteBalance),\n    focal_length_in_35_mm_format: Option(Int),\n    scene_capture_type: Option(SceneCaptureType),\n    lens_info: Option(List(Fraction)),\n    lens_make: Option(String),\n    lens_model: Option(String),\n    composite_image: Option(CompositeImage),\n    gps_latitude_ref: Option(String),\n    gps_latitude: Option(GPSCoordinates),\n    gps_longitude_ref: Option(String),\n    gps_longitude: Option(GPSCoordinates),\n    gps_altitude_ref: Option(GPSAltitudeRef),\n    gps_altitude: Option(Float),\n  )\n}\n\nExifTagRecord(\n  make: Option(String),\n  model: Option(String),\n  orientation: Option(Orientation),\n  x_resolution: Option(Int),\n  y_resolution: Option(Int),\n  resolution_unit: Option(ResolutionUnit),\n  software: Option(String),\n  modify_date: Option(String),\n  host_computer: Option(String),\n  y_cb_cr_positioning: Option(YCbCrPositioning),\n  exposure_time: Option(Fraction),\n  f_number: Option(Fraction),\n  exposure_program: Option(ExposureProgram),\n  iso: Option(Int),\n  exif_version: Option(String),\n  date_time_original: Option(String),\n  create_date: Option(String),\n  offset_time: Option(String),\n  offset_time_original: Option(String),\n  offset_time_digitized: Option(String),\n  components_configuration: Option(List(ComponentsConfiguration)),\n  shutter_speed_value: Option(Fraction),\n  aperature_value: Option(Fraction),\n  brightness_value: Option(Float),\n  exposure_compensation: Option(Fraction),\n  metering_mode: Option(MeteringMode),\n  flash: Option(Flash),\n  focal_length: Option(Float),\n  subject_area: Option(List(Int)),\n  maker_data: Option(TBD),\n  sub_sec_time_original: Option(String),\n  sub_sec_time_digitized: Option(String),\n  flash_pix_version: Option(String),\n  color_space: Option(ColorSpace),\n  exif_image_width: Option(Int),\n  exif_image_height: Option(Int),\n  sensing_method: Option(SensingMethod),\n  scene_type: Option(SceneType),\n  exposure_mode: Option(ExposureMode),\n  white_balance: Option(WhiteBalance),\n  focal_length_in_35_mm_format: Option(Int),\n  scene_capture_type: Option(SceneCaptureType),\n  lens_info: Option(List(Fraction)),\n  lens_make: Option(String),\n  lens_model: Option(String),\n  composite_image: Option(CompositeImage),\n  gps_latitude_ref: Option(String),\n  gps_latitude: Option(GPSCoordinates),\n  gps_longitude_ref: Option(String),\n  gps_longitude: Option(GPSCoordinates),\n  gps_altitude_ref: Option(GPSAltitudeRef),\n  gps_altitude: Option(Float),\n)\n\n\nSynonyms:\nglexif/exif_tag.ExifTagRecord\nglexif/exif_tag ExifTagRecord","url":"glexif/exif_tag.html#ExifTagRecord"},{"doc":"glexif/exif_tag","title":"TBD","content":"pub type TBD {\n  TBD\n}\n Unparsed data that has to be figured out\nTBD\n\n\nSynonyms:\nglexif/exif_tag.TBD\nglexif/exif_tag TBD","url":"glexif/exif_tag.html#TBD"},{"doc":"glexif/exif_tag","title":"new","content":"pub fn new() -&gt; ExifTagRecord\n\nSynonyms:\nglexif/exif_tag.new\nglexif/exif_tag new","url":"glexif/exif_tag.html#new"},{"doc":"glexif/exif_tag","title":"glexif/exif_tag","content":"","url":"glexif/exif_tag.html"},{"doc":"glexif","title":"get_exif_data_for_file","content":"pub fn get_exif_data_for_file(file_path: String) -&gt; ExifTagRecord\n\nSynonyms:\nglexif.get_exif_data_for_file\nglexif get_exif_data_for_file","url":"glexif.html#get_exif_data_for_file"},{"doc":"glexif","title":"glexif","content":"","url":"glexif.html"}]);